
typed-descriptors: Descriptor classes for typed attributes and properties
=========================================================================

typed-descriptors is a small library of descriptor classes for type attributes and properties, featuring static and runtime typechecking, runtime validation and property caching.

GitHub repo: https://github.com/hashberg-io/typed-descriptors

.. toctree::
    :maxdepth: 3
    :caption: Contents:

    getting-started

.. include:: api-toc.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
